@@ -2,11 +2,10 @@ package Lingua::Translit::Tables;
 
 
 #
-# Copyright 2007-2008 by ...
-#   Alex Linke, <alinke@lingua-systems.com>
-#   Rona Linke, <rlinke@lingua-systems.com>
-#
-# $Id: Tables.pm 275 2008-04-29 07:57:47Z alinke $
+# Copyright (C) 2007-2008 ...
+#   Alex Linke <alinke@lingua-systems.com>
+#   Rona Linke <rlinke@lingua-systems.com>
+# Copyright (C) 2009 Lingua-Systems Software GmbH
 #
 
 
@@ -212,7 +211,7 @@ I<Common Classical MON>, reversible, Classical Mongolian to Latin
 In case you want to add your own transliteration tables to L<Lingua::Translit>,
 a developer manual (F<xml/manual/>) is available in HTML and plain text format.
 An online version is available at
-L<http://www.lingua-systems.com/products/translit/manual/>.
+L<http://www.lingua-systems.com/transliteration/Lingua-Translit-Perl-module/developer-manual/>.
 
 All necessary tools and templates to start with are provided as well.
 
@@ -242,7 +241,9 @@ Rona Linke <rlinke@lingua-systems.com>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2008, Alex Linke and Rona Linke. All rights reserved.
+Copyright (C) 2008 Alex Linke and Rona Linke
+
+Copyright (C) 2009 Lingua-Systems Software GmbH
 
 This module is free software. It may be used, redistributed
 and/or modified under the terms of either the GPL v2 or the
